package com.link.base.autorefresh.util;

import com.link.core.cllog.LCLogger;
import com.link.core.util.RedisUtil;
import com.link.core.util.StringUtils;
import com.link.core.util.redisclient.LinkRedisClient;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

public class AutoRefreshCacheUtil {
   public static final String AUTO_REFRESH_CACHE_LUA = "local key = KEYS[1]\nlocal exist = redis.call(\"EXISTS\", key)\nif exist == 0 then\n\tredis.call(\"SET\", key, 1)\n\treturn 1\nelse\n\tlocal next = tonumber(redis.call(\"INCR\", key))\n\treturn next\nend";

   public static boolean canExecRefreshQueue(String redisKey) {
      boolean canRefresh = false;
      if (StringUtils.isBlank(redisKey)) {
         return canRefresh;
      } else {
         LinkRedisClient jedis = null;

         boolean var7;
         try {
            jedis = RedisUtil.getJedis();
            int expireSeconds = 120;
            int queueLenth = 3;
            long startLen = jedis.llen(redisKey);
            if (startLen <= (long)queueLenth) {
               jedis.lpush(redisKey, "0");
               jedis.expire(redisKey, Integer.valueOf(expireSeconds));
               int sleepSeconds = 30;
               Thread.sleep((long)(1000 * sleepSeconds));
               long endLen = jedis.llen(redisKey);
               if (startLen + 1L != endLen) {
                  boolean var10 = canRefresh;
                  return var10;
               }

               jedis.del(redisKey);
               canRefresh = true;
               return canRefresh;
            }

            jedis.expire(redisKey, Integer.valueOf(expireSeconds));
            var7 = canRefresh;
         } catch (Exception var14) {
            Exception e = var14;
            e.printStackTrace();
            LCLogger.error().withMessage(e.getMessage()).flush();
            return canRefresh;
         } finally {
            RedisUtil.returnResource(jedis);
         }

         return var7;
      }
   }

   public static boolean canExecRefreshLua(String redisLuaKey) {
      boolean canRefresh = false;
      if (StringUtils.isBlank(redisLuaKey)) {
         return canRefresh;
      } else {
         LinkRedisClient jedis = null;

         boolean var21;
         try {
            jedis = RedisUtil.getJedis();
            List<String> keys = Collections.singletonList(redisLuaKey);
            long currentLuaTimes = (Long)jedis.eval("local key = KEYS[1]\nlocal exist = redis.call(\"EXISTS\", key)\nif exist == 0 then\n\tredis.call(\"SET\", key, 1)\n\treturn 1\nelse\n\tlocal next = tonumber(redis.call(\"INCR\", key))\n\treturn next\nend", keys, new ArrayList());
            if (currentLuaTimes != 1L) {
               boolean var20 = canRefresh;
               return var20;
            }

            int startLimitSeconds = 60;
            int maxLimitSeconds = 150;
            int increaseSeconds = 30;
            int sleepTimes = (maxLimitSeconds - startLimitSeconds) / increaseSeconds + 1;
            jedis.expire(redisLuaKey, startLimitSeconds + maxLimitSeconds);
            long lastLuaTimes = 1L;

            for(int i = 1; i <= sleepTimes; ++i) {
               boolean var13;
               if (i == 1) {
                  Thread.sleep((long)(1000 * startLimitSeconds));
                  currentLuaTimes = (Long)jedis.eval("local key = KEYS[1]\nlocal exist = redis.call(\"EXISTS\", key)\nif exist == 0 then\n\tredis.call(\"SET\", key, 1)\n\treturn 1\nelse\n\tlocal next = tonumber(redis.call(\"INCR\", key))\n\treturn next\nend", keys, new ArrayList());
                  if (2L == currentLuaTimes) {
                     var13 = true;
                     return var13;
                  }
               } else {
                  lastLuaTimes = currentLuaTimes;
                  Thread.sleep((long)(1000 * increaseSeconds));
                  currentLuaTimes = (Long)jedis.eval("local key = KEYS[1]\nlocal exist = redis.call(\"EXISTS\", key)\nif exist == 0 then\n\tredis.call(\"SET\", key, 1)\n\treturn 1\nelse\n\tlocal next = tonumber(redis.call(\"INCR\", key))\n\treturn next\nend", keys, new ArrayList());
                  if (currentLuaTimes == lastLuaTimes + 1L) {
                     var13 = true;
                     return var13;
                  }
               }
            }

            jedis.del(redisLuaKey);
            var21 = true;
         } catch (Exception var17) {
            Exception e = var17;
            e.printStackTrace();
            LCLogger.error().withMessage(e.getMessage()).flush();
            return canRefresh;
         } finally {
            RedisUtil.returnResource(jedis);
         }

         return var21;
      }
   }
}
